{*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.54';
  RDB_META_DATA_ITEMS_DATE = '2023-01-19';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"an'
      + 'gle":{"description":"Angle [deg]","items":{"type":"number"},"type":"ar'
      + 'ray"},"range_mean":{"description":"Mean range [m]","items":{"type":"nu'
      + 'mber"},"type":"array"},"amplitude_mean":{"description":"Mean amplitude'
      + ' [dB]","items":{"type":"number"},"type":"array"}},"description":"Angul'
      + 'ar notch filter parameters for window glass echoes","title":"Angular '
      + 'Notch Filter","required":["angle","range_mean","amplitude_mean"],"type'
      + '":"object"}'
    );

    Example : (''
      + '{"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],"ran'
      + 'ge_mean":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,'
      + '0.0675,0.06475],"amplitude_mean":[3.780913,3.780913,3.480913,3.120913,'
      + '2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}'
    );
  );

// Atmospheric parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"gr'
      + 'oup_velocity":{"description":"Group velocity of laser beam '
      + '[m/s]","type":"number"},"pressure_sl":{"description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]","type":"number"},"temperature":{"description":"Temperature '
      + 'along measurement path '
      + '[\u00b0C]","type":"number"},"wavelength":{"description":"Laser '
      + 'wavelength [nm]","type":"number"},"pressure":{"description":"Pressure '
      + 'along measurment path '
      + '[mbar]","type":"number"},"rel_humidity":{"description":"Relative '
      + 'humidity along measurement path '
      + '[%]","type":"number"},"amsl":{"description":"Height above mean sea '
      + 'level (AMSL) '
      + '[m]","type":"number"},"attenuation":{"description":"Atmospheric '
      + 'attenuation [1/km]","type":"number"}},"description":"Atmospheric '
      + 'parameters","title":"Atmospheric Parameters","required":["temperature"'
      + ',"pressure","rel_humidity","pressure_sl","amsl","group_velocity","atte'
      + 'nuation","wavelength"],"type":"object"}'
    );

    Example : (''
      + '{"group_velocity":299711000.0,"pressure_sl":970,"temperature":7,"wavel'
      + 'ength":1550,"pressure":970,"rel_humidity":63,"amsl":0,"attenuation":0.'
      + '028125}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"be'
      + 'am_divergence":{"minimum":0,"description":"Beam divergence in far '
      + 'field [rad]","exclusiveMinimum":false,"type":"number"},"beam_exit_diam'
      + 'eter":{"minimum":0,"description":"Beam width at exit aperture '
      + '[m]","exclusiveMinimum":false,"type":"number"}},"description":"Laser '
      + 'beam geometry details","title":"Beam Geometry","required":["beam_exit_'
      + 'diameter","beam_divergence"],"type":"object"}'
    );

    Example : (''
      + '{"beam_divergence":0.0003,"beam_exit_diameter":0.0072}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ty'
      + 'pes":{"uniqueItems":true,"items":{"oneOf":[{"$ref":"#/definitions/rect'
      + 'angle"},{"$ref":"#/definitions/checkerboard2x2"},{"$ref":"#/definition'
      + 's/chevron"},{"$ref":"#/definitions/circular_disk"},{"$ref":"#/definiti'
      + 'ons/cylinder"},{"$ref":"#/definitions/sphere"},{"$ref":"#/definitions/'
      + 'round_corner_cube_prism"}],"type":"object"},"type":"array"}},"descript'
      + 'ion":"List of control object type definitions","definitions":{"rectang'
      + 'le":{"allOf":[{"$ref":"#/definitions/common"},{"properties":{"width":{'
      + '"minimum":0,"description":"width in meters","exclusiveMinimum":true,"t'
      + 'ype":"number"},"shape":{"enum":["rectangle"],"type":"string"},"length"'
      + ':{"minimum":0,"description":"length in meters","exclusiveMinimum":true'
      + ',"type":"number"}},"description":"rectangle specific properties","requ'
      + 'ired":["shape","length","width"],"type":"object"}],"description":"rect'
      + 'angle","type":"object"},"common":{"properties":{"surface_type":{"enum"'
      + ':["retro_reflective_foil","diffuse"],"description":"surface material '
      + 'type","type":"string"},"description":{"description":"string describing'
      + ' the object","type":"string"},"shape":{"enum":["rectangle","checkerboa'
      + 'rd2x2","chevron","circular_disk","cylinder","sphere","round_corner_cub'
      + 'e_prism"],"description":"shape '
      + 'identifier","type":"string"},"name":{"description":"unique type '
      + 'identifier","minLength":3,"type":"string"}},"description":"common '
      + 'object properties","required":["name","shape"],"type":"object"},"round'
      + '_corner_cube_prism":{"allOf":[{"$ref":"#/definitions/common"},{"proper'
      + 'ties":{"offset":{"description":"offset in meters, e.g. reflector '
      + 'constant (optional)","type":"number"},"shape":{"enum":["round_corner_c'
      + 'ube_prism"],"description":"shape identifier","type":"string"},"diamete'
      + 'r":{"minimum":0,"description":"diameter in '
      + 'meters","exclusiveMinimum":true,"type":"number"}},"description":"round'
      + ' corner cube prism specific properties","required":["shape","diameter"'
      + '],"type":"object"}],"description":"round corner cube prism","type":"ob'
      + 'ject"},"cylinder":{"allOf":[{"$ref":"#/definitions/common"},{"properti'
      + 'es":{"shape":{"enum":["cylinder"],"description":"shape identifier","ty'
      + 'pe":"string"},"height":{"minimum":0,"description":"height in meters","'
      + 'exclusiveMinimum":true,"type":"number"},"diameter":{"minimum":0,"descr'
      + 'iption":"diameter in meters","exclusiveMinimum":true,"type":"number"}}'
      + ',"description":"cylinder specific properties","required":["shape","dia'
      + 'meter","height"],"type":"object"}],"description":"cylinder","type":"ob'
      + 'ject"},"checkerboard2x2":{"allOf":[{"$ref":"#/definitions/common"},{"p'
      + 'roperties":{"square_length":{"minimum":0,"description":"length of a '
      + 'square of the checkerboard in meters","exclusiveMinimum":true,"type":"'
      + 'number"},"shape":{"enum":["checkerboard2x2"],"description":"shape '
      + 'identifier","type":"string"}},"description":"checkerboard specific pro'
      + 'perties","required":["shape","square_length"],"type":"object"}],"descr'
      + 'iption":"checkerboard 2 by 2","type":"object"},"chevron":{"allOf":[{"$'
      + 'ref":"#/definitions/common"},{"properties":{"shape":{"enum":["chevron"'
      + '],"description":"shape identifier","type":"string"},"outside_edge_leng'
      + 'th":{"minimum":0,"description":"length of the two outer edges in meter'
      + 's","exclusiveMinimum":true,"type":"number"},"thickness":{"minimum":0,"'
      + 'description":"thickness in meters","exclusiveMinimum":true,"type":"num'
      + 'ber"}},"description":"chevron specific properties","required":["shape"'
      + ',"outside_edge_length","thickness"],"type":"object"}],"description":"c'
      + 'hevron","type":"object"},"circular_disk":{"allOf":[{"$ref":"#/definiti'
      + 'ons/common"},{"properties":{"offset":{"description":"offset in meters,'
      + ' e.g. reflector constant (optional)","type":"number"},"shape":{"enum":'
      + '["circular_disk"],"description":"shape identifier","type":"string"},"d'
      + 'iameter":{"minimum":0,"description":"diameter in meters","exclusiveMin'
      + 'imum":true,"type":"number"}},"description":"circular disk specific pro'
      + 'perties","required":["shape","diameter"],"type":"object"}],"descriptio'
      + 'n":"circular disk","type":"object"},"sphere":{"allOf":[{"$ref":"#/defi'
      + 'nitions/common"},{"properties":{"shape":{"enum":["sphere"],"descriptio'
      + 'n":"shape identifier","type":"string"},"diameter":{"minimum":0,"descri'
      + 'ption":"diameter in meters","exclusiveMinimum":true,"type":"number"}},'
      + '"description":"sphere specific properties","required":["shape","diamet'
      + 'er"],"type":"object"}],"description":"sphere","type":"object"}},"title'
      + '":"Control Object Catalog","required":["types"],"type":"object"}'
    );

    Example : (''
      + '{"types":[{"width":0.3,"description":"Rectangle (60cm x '
      + '30cm)","shape":"rectangle","name":"Rectangle '
      + '60x30","length":0.6},{"width":0.4,"description":"Rectangle (80cm x '
      + '40cm)","shape":"rectangle","name":"Rectangle '
      + '80x40","length":0.8},{"square_length":0.3,"description":"Checkerboard '
      + '(square length: '
      + '30cm)","shape":"checkerboard2x2","name":"Checkerboard2x2 '
      + '30"},{"square_length":0.5,"description":"Checkerboard (square length: '
      + '50cm)","shape":"checkerboard2x2","name":"Checkerboard2x2 '
      + '50"},{"description":"Chevron (a=24''''; '
      + 'b=4'''')","shape":"chevron","outside_edge_length":0.6096,"name":"Chevron'
      + ' 24''''/4''''","thickness":0.1016},{"surface_type":"diffuse","description"'
      + ':" Circular Disk (diameter: '
      + '50cm)","shape":"circular_disk","name":"Circular Disk 50","diameter":0.'
      + '5},{"offset":0.0,"surface_type":"retro_reflective_foil","description":'
      + '"flat circular reflector from retro-reflective '
      + 'foil","shape":"circular_disk","diameter":0.05,"name":"RIEGL flat '
      + 'reflector 50 mm"},{"offset":0.0,"surface_type":"retro_reflective_foil"'
      + ',"description":"flat circular reflector from retro-reflective '
      + 'foil","shape":"circular_disk","diameter":0.1,"name":"RIEGL flat '
      + 'reflector 100 mm"},{"offset":0.0,"surface_type":"retro_reflective_foil'
      + '","description":"flat circular reflector from retro-reflective '
      + 'foil","shape":"circular_disk","diameter":0.15,"name":"RIEGL flat '
      + 'reflector 150 mm"},{"surface_type":"retro_reflective_foil","descriptio'
      + 'n":"cylindrical reflector from retro-reflective '
      + 'foil","shape":"cylinder","diameter":0.05,"height":0.05,"name":"RIEGL '
      + 'cylindrical reflector 50 mm"},{"surface_type":"retro_reflective_foil",'
      + '"description":"cylindrical reflector from retro-reflective '
      + 'foil","shape":"cylinder","diameter":0.1,"height":0.1,"name":"RIEGL '
      + 'cylindrical reflector 100 mm"},{"description":"Sphere (diameter: 200 '
      + 'mm)","shape":"sphere","name":"Sphere 200 '
      + 'mm","diameter":0.2},{"offset":0.0,"description":"round corner cube '
      + 'prism","shape":"round_corner_cube_prism","name":"Corner Cube Prism 50 '
      + 'mm","diameter":0.05}],"comments":["This file contains a list of '
      + 'control object types (aka. ''catalog'').","Each type is described by an '
      + 'object,","which must contain at least the following parameters:","  - '
      + 'name: unique identifier of the type","  - shape: one of the following '
      + 'supported shapes:","      - rectangle","      - checkerboard2x2","'
      + '      - chevron","      - circular_disk","      - cylinder","      - '
      + 'sphere","      - round_corner_cube_prism","Depending on ''shape'', the '
      + 'following parameters must/may be specified:","  - rectangle:","      -'
      + ' length: length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height: height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or ''diffuse'')"]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"re'
      + 'ference_file":{"properties":{"file_uuid":{"description":"Control '
      + 'object file''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_path":{"description":"Path of the '
      + 'control object file relative to referring '
      + 'file","type":"string"}},"description":"Reference to a control object f'
      + 'ile","required":["file_uuid","file_path"],"type":"object"}},"descripti'
      + 'on":"Details about the control object reference '
      + 'file","type":"object","title":"Control Object Reference file"}'
    );

    Example : (''
      + '{"reference_file":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213",'
      + '"file_path":"../../../10_CONTROL_OBJECTS/ControlPoints.cpx"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"de'
      + 'tection_probability":{"description":"Detection probability [0..1]","it'
      + 'ems":{"type":"number"},"type":"array"},"amplitude":{"description":"Amp'
      + 'litude [dB]","items":{"type":"number"},"type":"array"}},"description":'
      + '"Detection probability as a function of amplitude","title":"Detection '
      + 'Probability","required":["amplitude","detection_probability"],"type":"'
      + 'object"}'
    );

    Example : (''
      + '{"detection_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]'
      + ',"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"de'
      + 'vice_build":{"description":"Device build '
      + 'variant","type":"string"},"serial_number":{"description":"Device '
      + 'serial number (e.g. '
      + 'S2221234)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel devices)",'
      + '"type":"string"},"channel_number":{"minimum":0,"description":"Laser '
      + 'channel number (not defined or 0: single channel device)","exclusiveMi'
      + 'nimum":false,"type":"integer"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"}},"description":"Details about the device '
      + 'used to acquire the point cloud","title":"Device Information","require'
      + 'd":["device_type","serial_number"],"type":"object"}'
    );

    Example : (''
      + '{"device_build":"","serial_number":"S2221234","device_type":"VZ-400i",'
      + '"channel_text":"","channel_number":0,"device_name":"Scanner 1"}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"pr'
      + 'imary":{"properties":{"ID":{"description":"Structure identifier","minI'
      + 'tems":2,"maxItems":2,"items":{"type":"integer"},"type":"array"},"conte'
      + 'nt":{"description":"Internal calibration values","items":{"type":"numb'
      + 'er"},"type":"array"}},"description":"Primary device geometry structure'
      + ' (mandatory)","required":["ID","content"],"type":"object"},"amu":{"pro'
      + 'perties":{"frameCC":{"minimum":0,"description":"Frame Circle Count '
      + '(number of LSBs per full rotation about frame axis)","exclusiveMinimum'
      + '":false,"type":"number"},"lineCC":{"minimum":0,"description":"Line '
      + 'Circle Count (number of LSBs per full rotation about line '
      + 'axis)","exclusiveMinimum":false,"type":"number"}},"description":"Angle'
      + ' Measurement Unit","type":"object"},"secondary":{"properties":{"ID":{"'
      + 'description":"Structure identifier","minItems":2,"maxItems":2,"items":'
      + '{"type":"integer"},"type":"array"},"content":{"description":"Internal '
      + 'calibration values","items":{"type":"number"},"type":"array"}},"descri'
      + 'ption":"Additional device geometry structure (optional)","required":["'
      + 'ID","content"],"type":"object"}},"description":"Scanner device '
      + 'geometry details","title":"Device '
      + 'Geometry","required":["primary"],"type":"object"}'
    );

    Example : (''
      + '{"primary":{"ID":[4,0],"content":[0]},"amu":{"frameCC":124000,"lineCC"'
      + ':124000},"secondary":{"ID":[91,0],"content":[0]}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"pr'
      + 'imary":{"properties":{"ID":{"description":"Structure identifier","minI'
      + 'tems":2,"maxItems":2,"items":{"type":"integer"},"type":"array"},"conte'
      + 'nt":{"description":"Internal calibration values","items":{"type":"numb'
      + 'er"},"type":"array"}},"description":"Primary device geometry structure'
      + ' (mandatory)","required":["ID","content"],"type":"object"}},"descripti'
      + 'on":"Scanner passive channel device geometry details","title":"Device '
      + 'Geometry Passive Channel","required":["primary"],"type":"object"}'
    );

    Example : (''
      + '{"primary":{"ID":[143,0],"content":[0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"re'
      + 'flectance_maximum":{"description":"Maximum possible reflectance in '
      + 'dB.","type":"number"},"amplitude_maximum":{"description":"Maximum '
      + 'possible amplitude in '
      + 'dB.","type":"number"},"deviation_maximum":{"description":"Maximum '
      + 'possible pulse shape deviation.","type":"number"},"amplitude_minimum":'
      + '{"description":"Minimum possible amplitude in dB.","type":"number"},"b'
      + 'ackground_radiation_maximum":{"description":"Maximum possible '
      + 'background radiation.","type":"number"},"reflectance_minimum":{"descri'
      + 'ption":"Minimum possible reflectance in '
      + 'dB.","type":"number"},"deviation_minimum":{"description":"Minimum '
      + 'possible pulse shape '
      + 'deviation.","type":"number"},"range_maximum":{"description":"Maximum '
      + 'possible range in meters.","type":"number"},"mta_zone_count_maximum":{'
      + '"description":"Maximum number of MTA '
      + 'zones.","type":"number"},"range_minimum":{"description":"Minimum '
      + 'possible range in meters.","type":"number"},"background_radiation_mini'
      + 'mum":{"description":"Minimum possible background radiation.","type":"n'
      + 'umber"},"echo_count_maximum":{"description":"Maximum number of echoes '
      + 'a laser shot can have.","type":"number"}},"description":"Limits of the'
      + ' measured values output by the device. The limits depend on the device'
      + ' type, measurement program and/or scan '
      + 'pattern.","type":"object","title":"Device Output Limits"}'
    );

    Example : (''
      + '{"reflectance_maximum":100.0,"background_radiation_maximum":0,"amplitu'
      + 'de_maximum":100.0,"deviation_minimum":-1,"deviation_maximum":32767,"ra'
      + 'nge_maximum":10000.0,"background_radiation_minimum":0,"reflectance_min'
      + 'imum":-100.0,"amplitude_minimum":0.0,"mta_zone_count_maximum":7,"range'
      + '_minimum":2.9}'
    );
  );

// Details about the devices used to acquire the point cloud
const
  RDB_RIEGL_DEVICES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.devices';
    Title       : 'Devices Information';
    Description : 'Details about the devices used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails about the devices used to acquire the point cloud (e.g. when '
      + 'merging point clouds of different devices)","type":"array","items":{"p'
      + 'roperties":{"device_build":{"description":"Device build '
      + 'variant","type":"string"},"signed":{"description":"Flag that is set '
      + 'when the original ''riegl.device'' entry in the source file was '
      + 'correctly '
      + 'signed.","type":"boolean"},"serial_number":{"description":"Device '
      + 'serial number (e.g. '
      + 'S2221234)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel devices)",'
      + '"type":"string"},"channel_number":{"minimum":0,"description":"Laser '
      + 'channel number (not defined or 0: single channel device)","exclusiveMi'
      + 'nimum":false,"type":"integer"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner systems)","type":"stri'
      + 'ng"}},"required":["device_type","serial_number"],"type":"object"},"tit'
      + 'le":"Devices Information"}'
    );

    Example : (''
      + '[{"device_build":"","signed":false,"serial_number":"S2221234","device_'
      + 'type":"VZ-400i","channel_text":"","channel_number":0,"device_name":"Sc'
      + 'anner 1"},{"device_build":"","signed":true,"serial_number":"S2222680",'
      + '"device_type":"VQ-1560i-DW","channel_text":"","channel_number":1,"devi'
      + 'ce_name":"Scanner 2"},{"device_build":"","signed":true,"serial_number"'
      + ':"S2222680","device_type":"VQ-1560i-DW","channel_text":"","channel_num'
      + 'ber":2,"device_name":"Scanner 3"}]'
    );
  );

// Dyntrig
const
  RDB_RIEGL_DYNTRIG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.dyntrig';
    Title       : 'Dyntrig';
    Description : 'Dyntrig';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"of'
      + 'fset":{"description":"Offset in units of dB, for calculation of line",'
      + '"type":"number"},"pre":{"properties":{"a":{"description":"...","minIte'
      + 'ms":1,"maxItems":2080,"items":{"type":"number"},"type":"array"},"nc":{'
      + '"minimum":0,"maximum":255,"description":"Number of '
      + 'entries","type":"integer"}},"description":"Dyntrig pre values","requir'
      + 'ed":["nc","a"],"type":"object"},"scale":{"description":"Scale in units'
      + ' of dB, for calculation of line: line number N=(amplitude-offset)/scal'
      + 'e","type":"number"},"post":{"properties":{"a":{"description":"...","mi'
      + 'nItems":1,"maxItems":2080,"items":{"type":"number"},"type":"array"},"n'
      + 'c":{"minimum":0,"maximum":255,"description":"Number of '
      + 'entries","type":"integer"}},"description":"Dyntrig post values","requi'
      + 'red":["nc","a"],"type":"object"},"tab":{"description":"...","minItems"'
      + ':1,"maxItems":128,"items":{"properties":{"thra2":{"description":"Pre-t'
      + 'rigger threshold in units of '
      + 'dB","type":"number"},"del1":{"description":"Length of constant '
      + 'post-trigger threshold elevation in units of '
      + 'm","type":"number"},"dec2":{"description":"Rise of pre-trigger '
      + 'threshold after del2 in units of '
      + 'dB/m","type":"number"},"dec1":{"description":"Decay of post-trigger '
      + 'threshold after del1 in units of '
      + 'dB/m","type":"number"},"del2":{"description":"Length of constant '
      + 'pre-trigger threshold elevation in units of '
      + 'm","type":"number"},"thra1":{"description":"Post-trigger threshold in '
      + 'units of dB","type":"number"}},"description":"...","required":["thra1"'
      + ',"del1","dec1","thra2","del2","dec2"],"type":"object"},"type":"array"}'
      + '},"description":"Dyntrig","title":"Dyntrig"}'
    );

    Example : (''
      + '{"offset":0.0,"pre":{"a":[78,86,126,134,31],"nc":128},"scale":1.0,"pos'
      + 't":{"a":[78,86,126,134,31],"nc":128},"tab":[{"thra2":0.0,"del1":0.0,"d'
      + 'ec2":0.0,"dec1":0.0,"del2":0.0,"thra1":0.0}]}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ec'
      + 'ho_file":{"properties":{"file_uuid":{"description":"File''s Universally'
      + ' Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Echo file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"description":"Details about echo '
      + 'files","title":"Echo '
      + 'Information","required":["echo_file"],"type":"object"}'
    );

    Example : (''
      + '{"echo_file":{"file_uuid":"26a03615-67c0-4bea-8fe8-c577378fe661","file'
      + '_extension":"owp"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails for exponential decomposition of full waveform data","additional'
      + 'Properties":false,"definitions":{"channel":{"properties":{"scale":{"de'
      + 'scription":"amplitude calibration","type":"number"},"a_lin":{"minimum"'
      + ':0,"description":"relative linear amplitude range [0..1]","exclusiveMa'
      + 'ximum":false,"exclusiveMinimum":false,"maximum":1,"type":"number"},"pa'
      + 'rameter":{"properties":{"B":{"description":"imaginary part of '
      + 'amplitude factor in units of full-scale","items":{"type":"number"},"ty'
      + 'pe":"array"},"omega":{"description":"angular frequency in Hz","items":'
      + '{"type":"number"},"type":"array"},"gamma":{"description":"decay in 1/s'
      + 'econd","items":{"type":"number"},"type":"array"},"A":{"description":"r'
      + 'eal part of amplitude factor in units of full-scale","items":{"type":"'
      + 'number"},"type":"array"}},"description":"parameters of the syswave '
      + 'exponential sum","required":["A","B","gamma","omega"],"type":"object"}'
      + ',"delay":{"description":"delay calibration in seconds","type":"number"'
      + '}},"required":["delay","scale","parameter"],"type":"object"}},"pattern'
      + 'Properties":{"^[0-9]+$":{"$ref":"#/definitions/channel","description":'
      + '"one field per channel, field name is channel '
      + 'index"}},"title":"Exponential Decomposition","type":"object"}'
    );

    Example : (''
      + '{"0":{"scale":1.0,"a_lin":0.27,"parameter":{"B":[-3.9813032150268555,0'
      + '.08622030913829803,-0.3152860999107361],"omega":[352020896.0,364792755'
      + '2.0,-1977987072.0],"gamma":[-1094726528.0,-769562752.0,-848000064.0],"'
      + 'A":[0.9772450923919678,0.3354335129261017,-1.312678575515747]},"delay"'
      + ':3.783458418887631e-09},"1":{"scale":1.0,"a_lin":0.9,"parameter":{"B":'
      + '[-3.9,0.0,-0.3],"omega":[352020896.0,3647927552.0,-1977987072.0],"gamm'
      + 'a":[-1094726528.0,-769562752.0,-848000064.0],"A":[0.9,0.3,-1.3]},"dela'
      + 'y":3.5e-09}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"am'
      + 'plitude_db":{"items":{"type":"number"},"type":"array"},"range_offset_s'
      + 'ec_high_power":{"items":{"type":"number"},"type":"array"},"range_offse'
      + 't_sec_low_power":{"items":{"type":"number"},"type":"array"},"amplitude'
      + '_lsb_low_power":{"items":{"type":"number"},"type":"array"},"amplitude_'
      + 'lsb_high_power":{"items":{"type":"number"},"type":"array"}},"descripti'
      + 'on":"riegl.gaussian_decomposition contains information relevant for '
      + 'extracting calibrated amplitudes and calibrated ranges from a Gaussian'
      + ' decomposition of full waveform data. This information is contained in'
      + ' a table with five columns. Two columns are to be used as input: '
      + 'amplitude_lsb_low_power and amplitude_lsb_high_power. The other three '
      + 'columns provide the outputs. Amplitude_db gives the calibrated '
      + 'amplitude in the optical regime in decibels. The range offset columns '
      + 'provide additive range offsets, given in units of seconds, for each '
      + 'channel.","title":"Gaussian Decomposition","required":["amplitude_lsb_'
      + 'low_power","amplitude_lsb_high_power","amplitude_db","range_offset_sec'
      + '_low_power","range_offset_sec_high_power"],"type":"object"}'
    );

    Example : (''
      + '{"amplitude_db":[],"range_offset_sec_high_power":[],"range_offset_sec_'
      + 'low_power":[],"amplitude_lsb_low_power":[],"amplitude_lsb_high_power":'
      + '[]}'
    );
  );

// Point cloud georeferencing information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud georeferencing information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"po'
      + 'se":{"description":"Coordinate Transformation Matrix to transform from'
      + ' File Coordinate System to Global Coordinate Reference System. 4x4 '
      + 'matrix stored as two dimensional array, row major order.","minItems":4'
      + ',"maxItems":4,"items":{"description":"rows","minItems":4,"maxItems":4,'
      + '"items":{"description":"columns","type":"number"},"type":"array"},"typ'
      + 'e":"array"},"crs":{"properties":{"epsg":{"minimum":0,"description":"EP'
      + 'SG code","type":"integer"},"name":{"description":"Coordinate reference'
      + ' system name","type":"string"},"wkt":{"description":"\"Well-Known '
      + 'Text\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan'
      + 'dards/wkt-crs)","type":"string"}},"description":"Global Coordinate '
      + 'Reference System. Please note that only 3D Cartesian Coordinate '
      + 'Systems are allowed.","type":"object"}},"description":"Point cloud '
      + 'georeferencing information","type":"object","title":"Geo Tag"}'
    );

    Example : (''
      + '{"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063'
      + '882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113'
      + '8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0'
      + '.0,0.0,0.0,1.0]],"crs":{"epsg":4978,"name":"WGS84 '
      + 'Geocentric","wkt":"GEOCCS[\"WGS84 Geocentric\",DATUM[\"WGS84\",SPHEROI'
      + 'D[\"WGS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],AU'
      + 'THORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.0000000000000000,AU'
      + 'THORITY[\"EPSG\",\"8901\"]],UNIT[\"Meter\",1.00000000000000000000,AUTH'
      + 'ORITY[\"EPSG\",\"9001\"]],AXIS[\"X\",OTHER],AXIS[\"Y\",EAST],AXIS[\"Z\'
      + '",NORTH],AUTHORITY[\"EPSG\",\"4978\"]]"}}'
    );
  );

// Geometric scale factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric scale factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","minimum":0,"desc'
      + 'ription":"Geometric scale factor applied to point '
      + 'coordinates","exclusiveMinimum":true,"type":"number"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"tr'
      + 'ajectory_file":{"properties":{"file_uuid":{"description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Trajectory '
      + 'file extension, without the leading '
      + 'dot","type":"string"}},"description":"Trajectory data used for '
      + 'georeferencing of the point cloud","required":["file_extension"],"type'
      + '":"object"},"body_coordinate_system_type":{"enum":["NED","ENU"],"descr'
      + 'iption":"BODY coordinate frame (NED: North-East-Down, ENU: '
      + 'East-North-Up), default: NED","type":"string"},"trajectory_offsets":{"'
      + 'properties":{"offset_north":{"description":"[m]","type":"number"},"ver'
      + 'sion":{"description":"Meaning of offset values and how to apply them; '
      + 'version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch'
      + ')*Rx(offset_roll)","type":"integer"},"offset_pitch":{"description":"[d'
      + 'eg]","type":"number"},"offset_height":{"description":"[m]","type":"num'
      + 'ber"},"offset_yaw":{"description":"[deg]","type":"number"},"offset_rol'
      + 'l":{"description":"[deg]","type":"number"},"offset_east":{"description'
      + '":"[m]","type":"number"},"offset_time":{"description":"[s]","type":"nu'
      + 'mber"}},"description":"Correction offsets applied to the trajectory da'
      + 'ta","type":"object"},"socs_to_body_matrix":{"description":"Coordinate '
      + 'Transformation Matrix to transform from Scanner''s Own Coordinate '
      + 'System to Body Coordinate System. 4x4 matrix stored as two dimensional'
      + ' array, row major order.","minItems":4,"maxItems":4,"items":{"descript'
      + 'ion":"rows","minItems":4,"maxItems":4,"items":{"description":"columns"'
      + ',"type":"number"},"type":"array"},"type":"array"},"socs_to_rocs_matrix'
      + '":{"description":"Coordinate Transformation Matrix to transform from '
      + 'Scanner''s Own Coordinate System to Record Coordinate System. 4x4 '
      + 'matrix stored as two dimensional array, row major order.","minItems":4'
      + ',"maxItems":4,"items":{"description":"rows","minItems":4,"maxItems":4,'
      + '"items":{"description":"columns","type":"number"},"type":"array"},"typ'
      + 'e":"array"}},"description":"Parameters used for georeferencing of the '
      + 'point cloud","type":"object","title":"Georeferencing Parameters"}'
    );

    Example : (''
      + '{"trajectory_file":{"file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660"'
      + ',"file_extension":"pofx"},"body_coordinate_system_type":"NED","traject'
      + 'ory_offsets":{"offset_north":0.07,"version":0,"offset_pitch":0.01,"off'
      + 'set_height":-0.2,"offset_yaw":-0.45,"offset_roll":0.03,"offset_east":0'
      + '.15,"offset_time":18.007},"socs_to_body_matrix":[[-0.269827776749716,-'
      + '0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051'
      + '7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,'
      + '0.0],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Map of item names
const
  RDB_RIEGL_ITEM_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.item_names';
    Title       : 'Item Names';
    Description : 'Map of item names';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Ma'
      + 'p of item names","additionalProperties":false,"patternProperties":{"^-'
      + '?[0-9]+$":{"description":"One field per item, field name is item id, '
      + 'field value is item name","type":"string"}},"title":"Item '
      + 'Names","type":"object"}'
    );

    Example : (''
      + '{"1":"Name of item with id 1","-1":"Name of item with id '
      + '-1","47":"Name of item with id 47","2":"Name of item with id 2"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Li'
      + 'cense keys for software features","additionalProperties":false,"patter'
      + 'nProperties":{"^.*$":{"description":"Each field of the object '
      + 'represents a feature and holds a list of license keys, where the field'
      + ' name is the feature '
      + 'name.","minItems":1,"items":{"description":"License key (example: '
      + '''46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73'')","type":"string"},"type":"array"}},"title":"Software '
      + 'License Keys","type":"object"}'
    );

    Example : (''
      + '{"MTA resolution":["468E020A - 39A922E4 - B681A184 - 673E3D72"],"Full '
      + 'Waveform Analysis Topography":["0FD5FF07 - 011A1255 - 9F76CACA - '
      + '8D2ED557"],"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73"],"Full Waveform Analysis Topography with GPU '
      + 'support":["8AB44126 - 23B92250 - 16E2689F - 34EF7E7B"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"zo'
      + 'ne_width":{"minimum":0,"description":"Width of a MTA zone in meter.","'
      + 'type":"number"},"modulation_depth":{"minimum":0,"description":"Depth '
      + 'of pulse position modulation in meter.","type":"number"},"zone_count":'
      + '{"minimum":0,"description":"Maximum number of MTA '
      + 'zones.","maximum":255,"type":"integer"}},"description":"Parameters for'
      + ' MTA processing","type":"object","title":"MTA Settings"}'
    );

    Example : (''
      + '{"zone_width":149.896225,"modulation_depth":9.368514,"zone_count":23}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"de'
      + 'lta":{"description":"Delta between table entries [m], first entry is '
      + 'at range = 0 m","type":"number"},"content":{"description":"Correction '
      + 'value [m] to be added to the raw range","minItems":1,"maxItems":2000,"'
      + 'items":{"type":"number"},"type":"array"}},"description":"Lookup table '
      + 'for range correction based on raw range","title":"Near Range '
      + 'Correction Table","required":["delta","content"],"type":"object"}'
    );

    Example : (''
      + '{"delta":0.512,"content":[0.0]}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ra'
      + 'nge_sigma":{"description":"Sigma range [m]","items":{"type":"number"},'
      + '"type":"array"},"amplitude_sigma":{"description":"Sigma amplitude [dB]'
      + '","items":{"type":"number"},"type":"array"},"amplitude":{"description"'
      + ':"Amplitude [dB]","items":{"type":"number"},"type":"array"}},"descript'
      + 'ion":"Standard deviation for range and amplitude as a function of '
      + 'amplitude","title":"Noise Estimates","required":["amplitude","range_si'
      + 'gma","amplitude_sigma"],"type":"object"}'
    );

    Example : (''
      + '{"range_sigma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,'
      + '0.016,0.014],"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.'
      + '54,0.482,0.432,0.39,0.354],"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.'
      + '0,8.0,9.0,10.0]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ra'
      + 'nge_maximum":{"description":"Maximum range [m]","type":"number"},"ampl'
      + 'itude_maximum":{"minimum":0,"description":"Maximum amplitude '
      + '[dB]","type":"number"},"range_minimum":{"description":"Minimum range '
      + '[m]","type":"number"}},"description":"Notch filter parameters for '
      + 'window glass echoes","title":"Notch Filter","required":["range_minimum'
      + '","range_maximum","amplitude_maximum"],"type":"object"}'
    );

    Example : (''
      + '{"range_maximum":0.2,"amplitude_maximum":18.0,"range_minimum":-0.5}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"si'
      + 'ze_llcs":{"$ref":"#/definitions/pixel_size","description":"Size of '
      + 'pixels in a locally levelled cartesian coordinate system (xy). This is'
      + ' only used for pixels based on a map projection."},"size":{"$ref":"#/d'
      + 'efinitions/pixel_size","description":"Size of pixels in file '
      + 'coordinate system."}},"description":"Details about the pixels '
      + 'contained in the '
      + 'file","definitions":{"pixel_size":{"description":"Size of pixels.","mi'
      + 'nItems":2,"maxItems":2,"items":{"minimum":0,"description":"Length of '
      + 'pixel edge [m].","type":"number"},"type":"array"}},"title":"Pixel '
      + 'Information","required":["size"],"type":"object"}'
    );

    Example : (''
      + '{"size_llcs":[0.5156575252891171,0.5130835356683303],"size":[0.5971642'
      + '834779395,0.5971642834779395]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"pl'
      + 'ane_patch_file_one":{"$ref":"#/definitions/file_reference","descriptio'
      + 'n":"Reference to the plane patch file one"},"plane_patch_file_two":{"$'
      + 'ref":"#/definitions/file_reference","description":"Reference to the '
      + 'plane patch file two"}},"description":"Details about the plane patch '
      + 'matching process","definitions":{"file_reference":{"properties":{"file'
      + '_uuid":{"description":"Plane patch file''s Universally Unique '
      + 'Identifier (RFC '
      + '4122)","type":"string"},"file_path":{"description":"Path of the plane '
      + 'patch file relative to the match '
      + 'file","type":"string"}},"description":"Reference to a plane patch file'
      + '","required":["file_uuid","file_path"],"type":"object"}},"title":"Plan'
      + 'e Patch Matching","required":["plane_patch_file_one","plane_patch_file'
      + '_two"],"type":"object"}'
    );

    Example : (''
      + '{"plane_patch_file_one":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b'
      + '4213","file_path":"Record009_Line001/191025_121410_Scanner_1.ptch"},"p'
      + 'lane_patch_file_two":{"file_uuid":"fa47d509-a64e-49ce-8b14-ff3130fbefa'
      + '9","file_path":"project.ptch"}}'
    );
  );

// Statistics about plane patches found by plane patch extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by plane patch extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"to'
      + 'tal_horizontal_area":{"description":"sum of all plane patch areas '
      + 'projected to horizontal plane '
      + '[m\u00b2]","type":"number"},"total_area":{"description":"sum of all '
      + 'plane patch areas '
      + '[m\u00b2]","type":"number"}},"description":"Statistics about plane '
      + 'patches found by plane patch extractor","type":"object","title":"Plane'
      + ' Patch Statistics"}'
    );

    Example : (''
      + '{"total_horizontal_area":13954.601,"total_area":14007.965}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"cl'
      + 'asses":{"patternProperties":{"^[0-9]+$":{"description":"one field per '
      + 'class, field name is class number, field value is class '
      + 'name","type":"string"}},"description":"Class definition table","additi'
      + 'onalProperties":false,"type":"object"},"settings":{"oneOf":[{"$ref":"#'
      + '/definitions/method-1"},{"$ref":"#/definitions/method-2"}],"descriptio'
      + 'n":"Classification settings, details see documentation of '
      + 'rdbplanes","type":"object"}},"description":"Settings and classes for '
      + 'plane slope classification","definitions":{"method-1":{"properties":{"'
      + 'maximum_inclination_angle_horizontal":{"minimum":-360.0,"description":'
      + '"maximum inclination angle of horizontal plane patches [deg]","maximum'
      + '":360.0,"type":"number"},"plane_classification_method":{"minimum":1,"d'
      + 'escription":"method ID '
      + '(=1)","maximum":1,"type":"integer"}},"description":"Classification '
      + 'method 1","required":["plane_classification_method","maximum_inclinati'
      + 'on_angle_horizontal"],"type":"object"},"method-2":{"properties":{"slop'
      + 'ing_plane_classes_maximum_angle":{"minimum":-360.0,"description":"maxi'
      + 'mum inclination angle of sloping plane patches [deg]","maximum":360.0,'
      + '"type":"number"},"plane_classification_method":{"minimum":2,"descripti'
      + 'on":"method ID (=2)","maximum":2,"type":"integer"},"sloping_plane_clas'
      + 'ses_minimum_angle":{"minimum":-360.0,"description":"minimum '
      + 'inclination angle of sloping plane patches '
      + '[deg]","maximum":360.0,"type":"number"}},"description":"Classification'
      + ' method 2","required":["plane_classification_method","sloping_plane_cl'
      + 'asses_minimum_angle","sloping_plane_classes_maximum_angle"],"type":"ob'
      + 'ject"}},"title":"Plane Slope Class '
      + 'Info","required":["settings","classes"],"type":"object"}'
    );

    Example : (''
      + '{"classes":{"6":"vertical, pointing east","8":"vertical, pointing '
      + 'north","11":"sloping, pointing down and south","12":"sloping, pointing'
      + ' down and north","13":"sloping, pointing down and west","9":"vertical,'
      + ' pointing west","2":"sloping, pointing up and east","1":"horizontal, '
      + 'pointing up","4":"sloping, pointing up and north","14":"horizontal, '
      + 'pointing down","5":"sloping, pointing up and west","3":"sloping, '
      + 'pointing up and south","7":"vertical, pointing south","10":"sloping, '
      + 'pointing down and east"},"settings":{"sloping_plane_classes_maximum_an'
      + 'gle":70.0,"plane_classification_method":2,"sloping_plane_classes_minim'
      + 'um_angle":10.0}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Gr'
      + 'ouping and sorting of point attributes for visualization purposes","ad'
      + 'ditionalProperties":false,"patternProperties":{"^.*$":{"description":"'
      + 'Each field of the object represents a point attribute group and holds '
      + 'a list of point attributes, where the field name is the group '
      + 'name.","minItems":1,"items":{"description":"Point attribute full name '
      + 'or name pattern (perl regular expression '
      + 'syntax)","type":"string"},"type":"array"}},"title":"Point Attribute '
      + 'Groups","type":"object"}'
    );

    Example : (''
      + '{"Coordinates/Vectors":["riegl.xyz","riegl.range","riegl.theta","riegl'
      + '.phi"],"Other Attributes":["riegl.selected","riegl.visible"],"Time":["'
      + 'riegl.timestamp"],"Secondary '
      + 'Attributes":["riegl.mirror_facet","riegl.waveform_available"],"Primary'
      + ' '
      + 'Attributes":["riegl.reflectance","riegl.amplitude","riegl.deviation"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"co'
      + 'mments":{"description":"Comments","type":"string"},"project":{"descrip'
      + 'tion":"Project name","type":"string"},"field_of_application":{"enum":['
      + '"unknown","SLS","TLS","KLS","MLS","ULS","ALS","BLS","ILS"],"descriptio'
      + 'n":"Field of application","type":"string"}},"description":"Details '
      + 'about point cloud files","type":"object","title":"Point Cloud '
      + 'Information"}'
    );

    Example : (''
      + '{"comments":"Line 3","project":"Campaign '
      + '4","field_of_application":"ALS"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ba'
      + 'rometric_height_amsl":{"description":"Altitude determined based on the'
      + ' atmospheric pressure according to the standard atmosphere laws [m].",'
      + '"type":"number"},"orientation":{"properties":{"pitch_accuracy":{"minim'
      + 'um":0,"description":"Pitch angle accuracy [deg]","exclusiveMinimum":tr'
      + 'ue,"type":"number"},"pitch":{"minimum":-360,"description":"Pitch angle'
      + ' about scanner Y-axis [deg]","maximum":360,"type":"number"},"yaw_accur'
      + 'acy":{"minimum":0,"description":"Yaw angle accuracy [deg]","exclusiveM'
      + 'inimum":true,"type":"number"},"roll_accuracy":{"minimum":0,"descriptio'
      + 'n":"Roll angle accuracy [deg]","exclusiveMinimum":true,"type":"number"'
      + '},"roll":{"minimum":-360,"description":"Roll angle about scanner '
      + 'X-axis [deg]","maximum":360,"type":"number"},"yaw":{"minimum":-360,"de'
      + 'scription":"Yaw angle about scanner Z-axis '
      + '[deg]","maximum":360,"type":"number"}},"description":"Orientation '
      + 'values and orientation accuracies, measured with IMU or inclination se'
      + 'nsors.","required":["roll","pitch","yaw","roll_accuracy","pitch_accura'
      + 'cy","yaw_accuracy"],"type":"object"},"position":{"properties":{"crs":{'
      + '"properties":{"epsg":{"minimum":0,"description":"EPSG '
      + 'code","type":"integer"},"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"}},"description":"Global Coordinate Reference '
      + 'System","required":["epsg"],"type":"object"},"coordinate_2":{"descript'
      + 'ion":"Coordinate 2 as defined by axis 2 of the specified CRS (e.g., Y,'
      + ' Longitude)","type":"number"},"vertical_accuracy":{"minimum":0,"descri'
      + 'ption":"Vertical accuracy [m]","exclusiveMinimum":true,"type":"number"'
      + '},"coordinate_1":{"description":"Coordinate 1 as defined by axis 1 of '
      + 'the specified CRS (e.g., X, '
      + 'Latitude)","type":"number"},"coordinate_3":{"description":"Coordinate '
      + '3 as defined by axis 3 of the specified CRS (e.g., Z, Altitude)","type'
      + '":"number"},"horizontal_accuracy":{"minimum":0,"description":"Horizont'
      + 'al accuracy '
      + '[m]","exclusiveMinimum":true,"type":"number"}},"description":"Position'
      + ' coordinates and position accuracy values as measured by GNSS in the '
      + 'specified Coordinate Reference System (CRS)","required":["coordinate_1'
      + '","coordinate_2","coordinate_3","horizontal_accuracy","vertical_accura'
      + 'cy","crs"],"type":"object"}},"description":"Estimated position and '
      + 'orientation information as measured by GNSS, IMU or inclination '
      + 'sensors","title":"Pose '
      + 'Estimation","required":["orientation"],"type":"object"}'
    );

    Example : (''
      + '{"barometric_height_amsl":386.7457796227932,"orientation":{"pitch_accu'
      + 'racy":0.009433783936875745,"pitch":1.509153024827064,"yaw_accuracy":1.'
      + '0094337839368757,"roll_accuracy":0.009433783936875745,"roll":3.1474307'
      + '3066123,"yaw":101.87293630292045},"position":{"crs":{"epsg":4979,"wkt"'
      + ':"GEOGCS[\"WGS84 / Geographic\",DATUM[\"WGS84\",SPHEROID[\"WGS84\",637'
      + '8137.000,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\'
      + '",\"6326\"]],PRIMEM[\"Greenwich\",0.0000000000000000,AUTHORITY[\"EPSG\'
      + '",\"8901\"]],UNIT[\"Degree\",0.01745329251994329547,AUTHORITY[\"EPSG\"'
      + ',\"9102\"]],AXIS[\"Latitude\",NORTH],AXIS[\"Longitude\",EAST],AUTHORIT'
      + 'Y[\"EPSG\",\"4979\"]]"},"coordinate_2":15.645033406,"vertical_accuracy'
      + '":1.3314999341964722,"coordinate_1":48.655799473,"coordinate_3":362.71'
      + '24938964844,"horizontal_accuracy":0.810699999332428}}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ac'
      + 'celerometer":{"properties":{"offset":{"$ref":"#/definitions/vector","d'
      + 'escription":"Value to be subtracted from raw measurement values"},"y_a'
      + 'xis":{"$ref":"#/definitions/vector","description":"Sensitive Y axis of'
      + ' sensor at frame angle = 0"},"unit":{"minimum":0,"description":"Unit '
      + 'of raw data and calibration values, 1 LSB in 9.81 m/s\u00b2","exclusiv'
      + 'eMinimum":true,"type":"number"},"relative_nonlinearity":{"$ref":"#/def'
      + 'initions/vector","description":"Relative nonlinearity, dimensionless"}'
      + ',"z_axis":{"$ref":"#/definitions/vector","description":"Sensitive Z '
      + 'axis of sensor at frame angle = '
      + '0"},"origin":{"$ref":"#/definitions/vector","description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0"},"x_axis":{"$ref":"#/definitions/vector","description":"Sensitive X'
      + ' axis of sensor at frame angle = 0"}},"description":"Accelerometer det'
      + 'ails","required":["unit","x_axis","y_axis","z_axis","offset","origin",'
      + '"relative_nonlinearity"],"type":"object"},"magnetic_field_sensor":{"pr'
      + 'operties":{"offset":{"$ref":"#/definitions/vector","description":"Valu'
      + 'e to be subtracted from raw measurement values"},"y_axis":{"$ref":"#/d'
      + 'efinitions/vector","description":"Sensitive Y axis of sensor at frame '
      + 'angle = 0"},"unit":{"minimum":0,"description":"Unit of raw data and '
      + 'calibration values, 1 LSB in nT","exclusiveMinimum":true,"type":"numbe'
      + 'r"},"fixed":{"$ref":"#/definitions/vector","description":"Distortion '
      + 'of magnetic field caused by non-rotating scanner part"},"z_axis":{"$re'
      + 'f":"#/definitions/vector","description":"Sensitive Z axis of sensor at'
      + ' frame angle = 0"},"relative_nonlinearity":{"$ref":"#/definitions/vect'
      + 'or","description":"Relative nonlinearity, dimensionless"},"x_axis":{"$'
      + 'ref":"#/definitions/vector","description":"Sensitive X axis of sensor '
      + 'at frame angle = 0"}},"description":"Magnetic Field Sensor details","r'
      + 'equired":["unit","x_axis","y_axis","z_axis","offset","fixed","relative'
      + '_nonlinearity"],"type":"object"},"gyroscope":{"properties":{"offset":{'
      + '"$ref":"#/definitions/vector","description":"Value to be subtracted '
      + 'from raw measurement values"},"y_axis":{"$ref":"#/definitions/vector",'
      + '"description":"Sensitive Y axis of sensor at frame angle = '
      + '0"},"unit":{"minimum":0,"description":"Unit of raw data and '
      + 'calibration values, 1 LSB in rad/s","exclusiveMinimum":true,"type":"nu'
      + 'mber"},"relative_nonlinearity":{"$ref":"#/definitions/vector","descrip'
      + 'tion":"Relative nonlinearity, dimensionless"},"z_axis":{"$ref":"#/defi'
      + 'nitions/vector","description":"Sensitive Z axis of sensor at frame '
      + 'angle = '
      + '0"},"origin":{"$ref":"#/definitions/vector","description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0"},"x_axis":{"$ref":"#/definitions/vector","description":"Sensitive X'
      + ' axis of sensor at frame angle = 0"}},"description":"Gyroscope details'
      + '","required":["unit","x_axis","y_axis","z_axis","offset","origin","rel'
      + 'ative_nonlinearity"],"type":"object"}},"description":"Details on '
      + 'position and orientation sensors","definitions":{"vector":{"minItems":'
      + '3,"maxItems":3,"items":{"description":"Index 0=X, 1=Y, 2=Z '
      + 'component","type":"number"},"type":"array"}},"title":"Pose Sensors","r'
      + 'equired":["gyroscope","accelerometer","magnetic_field_sensor"],"type":'
      + '"object"}'
    );

    Example : (''
      + '{"accelerometer":{"offset":[-733.3636474609375,58.969032287597656,1060'
      + '.2550048828125],"y_axis":[-7.027288913726807,-44.12333679199219,14952.'
      + '3701171875],"unit":6.666666740784422e-05,"relative_nonlinearity":[0.0,'
      + '0.0,0.0],"z_axis":[1.639882206916809,15166.744140625,-116.997428894042'
      + '97],"origin":[0.026900000870227814,-0.03999999910593033,-0.08950000256'
      + '299973],"x_axis":[-15008.123046875,56.956390380859375,-60.517566680908'
      + '2]},"magnetic_field_sensor":{"offset":[-23812.052734375,5606.576660156'
      + '25,2493.28125],"y_axis":[0.00027888521435670555,-0.011427424848079681,'
      + '-5.204829722060822e-05],"unit":91.74311828613281,"fixed":[-1576.010498'
      + '046875,1596.081787109375,0.0],"z_axis":[0.00041987866279669106,7.87697'
      + '7906562388e-05,0.011407104320824146],"relative_nonlinearity":[0.0,0.0,'
      + '0.0],"x_axis":[-0.011162743903696537,-2.315962774446234e-05,0.00016818'
      + '844596855342]},"gyroscope":{"offset":[-50.92609786987305,146.156433105'
      + '46875,62.4327278137207],"y_axis":[-0.440765917301178,-0.78973996639251'
      + '71,119.5894775390625],"unit":0.00014544410805683583,"relative_nonlinea'
      + 'rity":[2.888176311444113e-07,1.06274164579645e-07,-1.7186295080634935e'
      + '-39],"z_axis":[0.555869996547699,119.22135162353516,0.467585027217865]'
      + ',"origin":[0.026900000870227814,-0.03999999910593033,-0.08950000256299'
      + '973],"x_axis":[-121.195556640625,0.8219714164733887,0.2313031703233719'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"co'
      + 'de_phase_mode":{"minimum":0,"description":"0: no synchronization, 1: '
      + 'toggle between 2 phases, 2: increment with phase_increment","maximum":'
      + '255,"type":"integer"},"pulse_interval":{"description":"Explicit table '
      + 'of the pulse position modulation used for MTA resolution. Table gives '
      + 'times between successive laser pulses in seconds.","items":{"minimum":'
      + '0,"type":"number"},"type":"array"},"phase_step":{"minimum":0,"descript'
      + 'ion":"Step width in phase of modulation code from line to line","maxim'
      + 'um":255,"type":"integer"},"num_mod_ampl":{"minimum":0,"description":"N'
      + 'umber of different modulation amplitudes (2: binary modulation)","maxi'
      + 'mum":255,"type":"integer"},"length":{"minimum":0,"description":"Length'
      + ' of code","maximum":255,"type":"integer"}},"description":"Laser pulse '
      + 'position modulation used for MTA resolution","title":"Pulse Position M'
      + 'odulation","required":["length","num_mod_ampl","pulse_interval"],"type'
      + '":"object"}'
    );

    Example : (''
      + '{"code_phase_mode":2,"pulse_interval":[2.759375e-06,2.759375e-06,2.759'
      + '375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-'
      + '06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.'
      + '821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.75937'
      + '5e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06'
      + ',2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.75'
      + '9375e-06,2.821875e-06],"phase_step":5,"num_mod_ampl":2,"length":31}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"mi'
      + 'nimum":{"description":"Minimum '
      + 'value","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation","type":"number"},"average":{"description":"Average '
      + 'value","type":"number"},"maximum":{"description":"Maximum '
      + 'value","type":"number"}},"description":"Statistics about target '
      + 'distance wrt. SOCS origin","title":"Range Statistics","required":["min'
      + 'imum","average","maximum","std_dev"],"type":"object"}'
    );

    Example : (''
      + '{"minimum":0.919,"std_dev":24.349,"average":15.49738,"maximum":574.35}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"nt'
      + '":{"minimum":0,"maximum":255,"description":"Number of traces","type":"'
      + 'integer"},"t":{"patternProperties":{"^[0-9]+$":{"$ref":"#/definitions/'
      + 'fp","description":"one field per channel, field name is channel index"'
      + '}},"additionalProperties":false,"type":"object"},"ns":{"minimum":0,"ma'
      + 'ximum":4095,"description":"Number of samples","type":"integer"},"mw":{'
      + '"minimum":0,"maximum":4095,"description":"Maximum weight","exclusiveMi'
      + 'nimum":true,"type":"number"},"a":{"description":"Amplitude [dB]","minI'
      + 'tems":1,"maxItems":256,"items":{"type":"number"},"type":"array"},"ex":'
      + '{"description":"DEPRECATED, use ''riegl.exponential_decomposition'' '
      + 'instead","type":"object"},"tbl":{"description":"various internal data"'
      + ',"minItems":1,"items":{"$ref":"#/definitions/fp_table"},"type":"array"'
      + '},"sr":{"minimum":0,"exclusiveMinimum":true,"description":"Sample rate'
      + ' [Hz]","type":"number"},"si":{"minimum":0,"maximum":255,"description":'
      + '"Start index (hw_start)","type":"number"}},"description":"Receiver Int'
      + 'ernals","definitions":{"fp_table":{"properties":{"nx":{"description":"'
      + 'number of x entries","max":2048,"min":1,"type":"integer"},"tv":{"minIt'
      + 'ems":1,"maxItems":2048,"items":{"oneOf":[{"$ref":"#/definitions/fp_tab'
      + 'le_row"},{"type":"number"}]},"type":"array"},"ch":{"description":"chan'
      + 'nel '
      + 'number","max":255,"min":0,"type":"integer"},"tc":{"description":"table'
      + ' data type '
      + 'code","max":255,"min":0,"type":"integer"},"ny":{"description":"number '
      + 'of y '
      + 'entries","max":2048,"min":1,"type":"integer"}},"desription":"scanner '
      + 'internal data","required":["ch","tc","nx","ny","tv"],"type":"object"},'
      + '"fp_table_row":{"minItems":1,"maxItems":2048,"items":{"type":"number"}'
      + ',"type":"array"},"fp":{"properties":{"w":{"minItems":1,"maxItems":256,'
      + '"items":{"minItems":5,"maxItems":5,"items":{"type":"number"},"type":"a'
      + 'rray"},"type":"array"},"s":{"minItems":1,"maxItems":256,"items":{"minI'
      + 'tems":1,"maxItems":4096,"items":{"type":"number"},"type":"array"},"typ'
      + 'e":"array"}},"description":"Fingerprint '
      + 'values","required":["s","w"],"type":"object"}},"title":"Receiver '
      + 'Internals","type":"object"}'
    );

    Example : (''
      + '{"nt":128,"t":{"0":{"w":[[78,86,126,134,31],[78,86,126,134,31]],"s":[['
      + '1.23,4.56],[7.89,0.12]]},"1":{"w":[[78,86,126,134,31],[78,86,126,134,3'
      + '1]],"s":[[1.23,4.56],[7.89,0.12]]}},"ns":400,"mw":31,"a":[-1.55],"tbl"'
      + ':[{"nx":5,"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],"ch":0,"tc":1,"ny":'
      + '2}],"sr":7959997000.0,"si":48}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"de'
      + 'lta":{"description":"Delta between table entries [m], first entry is '
      + 'at range = 0 m","type":"number"},"content":{"description":"Correction '
      + 'value [dB] to be added to the amplitude","minItems":1,"maxItems":2000,'
      + '"items":{"type":"number"},"type":"array"}},"description":"Lookup table'
      + ' for reflectance calculation based on amplitude and '
      + 'range","title":"Reflectance Calculation '
      + 'Table","required":["delta","content"],"type":"object"}'
    );

    Example : (''
      + '{"delta":0.150918,"content":[-33.01]}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-Range Reflectance Correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"li'
      + 'ne_angles_deg":{"description":"Angle [deg]","items":{"type":"number"},'
      + '"type":"array"},"ranges_m":{"description":"Range [m]","items":{"type":'
      + '"number"},"type":"array"},"reflectance_correction_db":{"description":"'
      + 'Near range reflectance correction in dB as a function of range over '
      + 'angle","items":{"description":"rows (each array corresponds to a '
      + 'range)","items":{"description":"columns (each value corresponds to an '
      + 'angle)","type":"number"},"type":"array"},"type":"array"}},"description'
      + '":"Range-dependent and scan-angle-dependent correction of reflectance '
      + 'reading","title":"Near-range reflectance correction","required":["rang'
      + 'es_m","line_angles_deg","reflectance_correction_db"],"type":"object"}'
    );

    Example : (''
      + '{"line_angles_deg":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],"ranges_m'
      + '":[0.0,1.0,2.0,3.0],"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,'
      + '0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.'
      + '8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,'
      + '0.1,0.05,0.01]]}'
    );
  );

// Scan pattern description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan pattern description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"se'
      + 'gments":{"properties":{"program":{"$ref":"#/definitions/program"},"lis'
      + 't":{"items":{"properties":{"stop":{"minimum":0.0,"description":"Stop '
      + 'angle in SOCS [deg]","maximum":720.0,"type":"number"},"increment":{"mi'
      + 'nimum":0.0,"description":"Increment of angle in SOCS [deg]","maximum":'
      + '90.0,"type":"number"},"start":{"minimum":0.0,"description":"Start '
      + 'angle in SOCS '
      + '[deg]","maximum":360.0,"type":"number"}},"description":"Line Scan Segm'
      + 'ent","required":["start","stop","increment"],"type":"object"},"type":"'
      + 'array"}},"description":"Segmented Line Scan Pattern","required":["list'
      + '"],"type":"object"},"line":{"properties":{"stop":{"minimum":0.0,"descr'
      + 'iption":"Stop angle in SOCS [deg]","maximum":720.0,"type":"number"},"i'
      + 'ncrement":{"minimum":0.0,"description":"Increment of angle in SOCS [de'
      + 'g]","maximum":90.0,"type":"number"},"start":{"minimum":0.0,"descriptio'
      + 'n":"Start angle in SOCS [deg]","maximum":360.0,"type":"number"},"progr'
      + 'am":{"$ref":"#/definitions/program"}},"description":"Line Scan Pattern'
      + '","required":["start","stop","increment"],"type":"object"},"rectangula'
      + 'r":{"properties":{"theta_stop":{"minimum":0.0,"description":"Stop '
      + 'theta angle in SOCS [deg]","maximum":180.0,"type":"number"},"theta_sta'
      + 'rt":{"minimum":0.0,"description":"Start theta angle in SOCS [deg]","ma'
      + 'ximum":180.0,"type":"number"},"phi_start":{"minimum":0.0,"description"'
      + ':"Start phi angle in SOCS [deg]","maximum":360.0,"type":"number"},"phi'
      + '_increment":{"minimum":0.0,"description":"Increment of phi angle in '
      + 'SOCS [deg]","maximum":90.0,"type":"number"},"program":{"$ref":"#/defin'
      + 'itions/program"},"phi_stop":{"minimum":0.0,"description":"Stop phi '
      + 'angle in SOCS [deg]","maximum":720.0,"type":"number"},"theta_increment'
      + '":{"minimum":0.0,"description":"Increment of theta angle in SOCS '
      + '[deg]","maximum":90.0,"type":"number"}},"description":"Rectangular '
      + 'Field Of View Scan Pattern","required":["phi_start","phi_stop","phi_in'
      + 'crement","theta_start","theta_stop","theta_increment"],"type":"object"'
      + '}},"description":"Scan pattern description","definitions":{"program":{'
      + '"properties":{"laser_prr":{"minimum":0,"description":"Laser Pulse '
      + 'Repetition Rate [Hz]","exclusiveMinimum":false,"type":"number"},"name"'
      + ':{"description":"Name of measurement '
      + 'program","type":"string"}},"description":"Measurement '
      + 'program","required":["name"],"type":"object"}},"title":"Scan Pattern"}'
    );

    Example : (''
      + '{"rectangular":{"theta_stop":130.0,"theta_start":30.0,"phi_start":45.0'
      + ',"phi_increment":0.04,"program":{"laser_prr":100000.0,"name":"High '
      + 'Speed"},"phi_stop":270.0,"theta_increment":0.04}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"sh'
      + 'ot_file":{"properties":{"file_uuid":{"description":"File''s Universally'
      + ' Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Shot file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"description":"Details about laser '
      + 'shot files","type":"object","title":"Shot Information"}'
    );

    Example : (''
      + '{"shot_file":{"file_uuid":"26a00815-67c0-4bff-8fe8-c577378fe663","file'
      + '_extension":"sodx"}}'
    );
  );

// Point filters applied in addition to the application-defined filters
const
  RDB_RIEGL_STORED_FILTERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.stored_filters';
    Title       : 'Stored Filters';
    Description : 'Point filters applied in addition to the application-defined filters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"fi'
      + 'lters":{"description":"List of point '
      + 'filters","items":{"properties":{"filter":{"description":"The RDB '
      + 'filter string to apply (e.g. when reading points or index), details '
      + 'see documentation of function '
      + 'select()","type":"string"},"description":{"description":"A brief '
      + 'description of the filter (e.g. for display in a '
      + 'tooltip)","type":"string"},"activated":{"description":"Apply (''true'') '
      + 'or ignore (''false'') this '
      + 'filter","type":"boolean"},"title":{"description":"A short filter title'
      + ' (e.g. for display in a selection '
      + 'list)","type":"string"}},"description":"Point filter definition","requ'
      + 'ired":["activated","title","description","filter"],"type":"object"},"t'
      + 'ype":"array"},"activated":{"description":"Apply (''true'') or ignore '
      + '(''false'') all filters","type":"boolean"}},"description":"Point filters'
      + ' applied in addition to the application-defined '
      + 'filters","title":"Stored '
      + 'filters","required":["activated","filters"],"type":"object"}'
    );

    Example : (''
      + '{"filters":[{"filter":"riegl.mta_uncertain_point == '
      + '0","description":"Ignore points with uncertain MTA zone '
      + 'assignment","activated":false,"title":"Ignore uncertain points from '
      + 'MTA resolution"},{"filter":"riegl.dyntrig_uncertain_point == '
      + '0","description":"Ignore points with an echo signal amplitude below '
      + 'the dynamic trigger","activated":false,"title":"Ignore points below '
      + 'dynamic trigger level"},{"filter":"riegl.point_outside_aabb_bocs == '
      + '0","description":"Ignore points that are outside the outer AABB in '
      + 'BOCS","activated":false,"title":"Ignore points outside outer '
      + 'AABB"},{"filter":"riegl.point_inside_aabb_bocs == '
      + '0","description":"Ignore points that are inside the inner AABB in '
      + 'BOCS","activated":false,"title":"Ignore points inside inner '
      + 'AABB"}],"activated":true}'
    );
  );

// Details of major system components like lidar sensors, cameras and navigation devices
const
  RDB_RIEGL_SYSTEM_DESCRIPTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.system_description';
    Title       : 'System Description';
    Description : 'Details of major system components like lidar sensors, cameras and navigation devices';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ti'
      + 'mestamp":{"description":"Date and time of creation (e.g. 2019-06-19T13'
      + ':32:10+02:00)","type":"string"},"system":{"description":"The actual '
      + 'system description, details see documentation of RIEGL System '
      + 'Description","type":"object"},"version":{"description":"Document '
      + 'format version","type":"string"},"$class":{"enum":["Document"],"descri'
      + 'ption":"Object class '
      + 'name","type":"string"},"author":{"description":"Name of the author '
      + 'that created the document","type":"string"}},"description":"Details of'
      + ' major system components like lidar sensors, cameras and navigation '
      + 'devices","title":"System Description","required":["$class","version","'
      + 'author","timestamp","system"],"type":"object"}'
    );

    Example : (''
      + '{"timestamp":"2022-09-30T11:56:26+00:00","system":{"details":"see '
      + 'documentation of RIEGL System '
      + 'Description"},"version":"1.2.1","$class":"Document","author":"RIEGL '
      + 'LMS GmbH, Austria"}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"In'
      + 'GaAs":{"$ref":"#/definitions/conversion_table","description":"Conversi'
      + 'on table for InGaAs channel"},"Si":{"$ref":"#/definitions/conversion_t'
      + 'able","description":"Conversion table for Si channel"},"InGaAs_Si_Diff'
      + 'erence":{"$ref":"#/definitions/conversion_table","description":"Conver'
      + 'sion table for InGaAs - Si difference"}},"description":"Conversion of '
      + 'background radiation raw values to temperatures in \u00b0C","definitio'
      + 'ns":{"conversion_table":{"properties":{"value":{"description":"LSB [1]'
      + '","items":{"type":"number"},"type":"array"},"temperature":{"descriptio'
      + 'n":"Temperature [\u00b0C]","items":{"type":"number"},"type":"array"}},'
      + '"required":["value","temperature"],"type":"object"}},"title":"Temperat'
      + 'ure Calculation Table","type":"object"}'
    );

    Example : (''
      + '{"InGaAs":{"value":[0.0,64.00097659230323,128.0019531846065,192.002929'
      + '7769097,256.0039063692129,320.00488296151616,384.0058595538194,448.006'
      + '8361461226,512.0078127384259],"temperature":[307.22196722535614,309.11'
      + '53478247277,311.1188086915047,313.10025350480055,315.2137946389828,317'
      + '.2172555057597,319.2207163725366,321.2021611858325,323.3157023200148]}'
      + ',"Si":{"value":[0.0,64.00097659230323,128.0019531846065,192.0029297769'
      + '097,256.0039063692129,320.00488296151616,384.0058595538194,448.0068361'
      + '461226,512.0078127384259],"temperature":[546.300048828125,548.81640512'
      + '12026,551.3143938500972,554.0144257850053,556.604252334815,559.2124464'
      + '488079,561.8022729986177,564.4104671126105,567.0002936624203]},"InGaAs'
      + '_Si_Difference":{"value":[1000.0,1100.090029602954,1200.04425183874,13'
      + '00.1342814416948,1400.0885036774805,1500.0427259132668,1600.1327555162'
      + '209,1700.0869777520065,1800.0411999877924],"temperature":[1749.9771111'
      + '17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711'
      + '1117893,1749.977111117893,1744.7813348796044,1681.9971312601092,1622.3'
      + '944822534868]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"so'
      + 'urce":{"enum":["unknown","RTC","GNSS"],"description":"Timestamp source'
      + '","type":"string"},"system":{"enum":["unknown","UTC","GPS"],"descripti'
      + 'on":"Time system (time '
      + 'standard)","type":"string"},"epoch":{"description":"Date and time of '
      + 'timestamp ''0'' as proposed by RFC 3339 (e.g. '
      + '2015-10-27T00:00:00+01:00).","type":"string"}},"description":"Base of '
      + 'timestamps (epoch)","title":"Time '
      + 'Base","required":["epoch","source"],"type":"object"}'
    );

    Example : (''
      + '{"source":"GNSS","system":"UTC","epoch":"2015-10-27T00:00:00+00:00"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ti'
      + 'me_interval":{"properties":{"minimum":{"description":"Minimum time '
      + 'interval [s]","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation of intervals '
      + '[s]","type":"number"},"average":{"description":"Average time interval '
      + '[s]","type":"number"},"maximum":{"description":"Maximum time interval '
      + '[s]","type":"number"}},"description":"Time interval statistics","requi'
      + 'red":["minimum","average","maximum","std_dev"],"type":"object"},"compa'
      + 'ny":{"description":"Company name","type":"string"},"navigation_frame":'
      + '{"enum":["unknown","NED","ENU"],"description":"Navigation frame (NED: '
      + 'North-East-Down, ENU: '
      + 'East-North-Up)","type":"string"},"device":{"description":"Navigation '
      + 'device, e.g. '
      + 'name/type/serial","type":"string"},"settings":{"description":"Settings'
      + ' used to calculate the trajectory (descriptive '
      + 'text)","type":"string"},"location":{"description":"Project location, '
      + 'e.g. city/state/country","type":"string"},"software":{"description":"S'
      + 'oftware that calculated the trajectory (this may be the same or '
      + 'different software than the one that created the '
      + 'file)","type":"string"},"project":{"description":"Project name","type"'
      + ':"string"},"field_of_application":{"enum":["unknown","SLS","TLS","KLS"'
      + ',"MLS","ULS","ALS","BLS","ILS"],"description":"Field of '
      + 'application","type":"string"}},"description":"Details about '
      + 'position+orientation files","title":"Trajectory Information","required'
      + '":["time_interval","navigation_frame"],"type":"object"}'
    );

    Example : (''
      + '{"time_interval":{"minimum":0.00500032,"std_dev":5.51e-07,"average":0.'
      + '00500053,"maximum":0.005004883},"company":"RIEGL '
      + 'LMS","navigation_frame":"NED","device":"IMU Model 12/1, Serial# '
      + '12345","settings":"default","location":"Horn","software":"Navigation '
      + 'Software XYZ","project":"Campaign 3","field_of_application":"MLS"}'
    );
  );

// Trigger-Timestamping-Unit/IP configuration
const
  RDB_RIEGL_TTIP_CONFIGURATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.ttip_configuration';
    Title       : 'TTIP Configuration';
    Description : 'Trigger-Timestamping-Unit/IP configuration';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ou'
      + 't_num_pulses":{"minimum":0,"description":"number of output pulses to '
      + 'be generated, 0 .. '
      + 'infinite","type":"integer"},"ext_signal":{"minimum":0,"description":"0'
      + ' .. use input signal, 1 .. use output signal of channel","type":"integ'
      + 'er"},"dmi_max_time":{"minimum":0,"description":"dmi, maximum time '
      + 'interval between trigger events [0.1 msec]","type":"integer"},"out_dur'
      + 'ation":{"minimum":0,"description":"output pulse duration [0.1 msec]","'
      + 'type":"integer"},"in_max_duration":{"minimum":0,"description":"stops '
      + 'measurement of pulse duration of input signal [0.1 msec]","type":"inte'
      + 'ger"},"num_channel":{"minimum":0,"description":"number of input/output'
      + ' channels","type":"integer"},"dmi_min_time":{"minimum":0,"description"'
      + ':"dmi, minimum time interval between trigger events [0.1 msec]","type"'
      + ':"integer"},"out_interval":{"minimum":0,"description":"output pulse '
      + 'interval [0.1 '
      + 'msec]","type":"integer"},"in_polarity":{"minimum":0,"description":"0 '
      + '.. positive edge, 1 .. negative edge","type":"integer"},"ext_delay":{"'
      + 'minimum":0,"description":"external trigger, time delay [0.1 '
      + 'msec]","type":"integer"},"channel":{"minimum":0,"description":"ID of '
      + 'input/output channel","type":"integer"},"in_max_delay":{"minimum":0,"d'
      + 'escription":"maximum delay to output pulse before fake event is '
      + 'generated [0.1 msec], zero indicates that no fake events are generated'
      + '","type":"integer"},"output_usage":{"minimum":0,"description":"0 .. no'
      + ' output, 1 .. output derived from internal clock, 2 .. output derived '
      + 'from dmi, 3 .. output derived from external signal, 4 .. output static'
      + ' low, 5 .. output static high","type":"integer"},"ext_subdivider":{"mi'
      + 'nimum":0,"description":"reduces the frequency, default 1","type":"inte'
      + 'ger"},"ttip_version":{"minimum":0,"description":"following main.sub.ss'
      + '.sss","type":"integer"},"out_delay":{"minimum":0,"description":"output'
      + ' pulse initial delay after start [0.1 '
      + 'msec]","type":"integer"},"input_descr":{"description":"descriptive '
      + 'string","type":"string"},"ext_channel":{"minimum":0,"description":"ID '
      + 'of channel used as external trigger input, 32 indicates none","type":"'
      + 'integer"},"ext_bitmask":{"minimum":0,"description":"defines which of '
      + 'the internal pulse generators are to be '
      + 'started","type":"integer"},"output_descr":{"description":"descriptive '
      + 'string","type":"string"},"dmi_dist_per_tick":{"description":"dmi, '
      + 'distance per tick, just informative '
      + '[m]","type":"number"},"dmi_incr":{"description":"dmi, increment in tic'
      + 'ks","type":"integer"},"in_min_duration":{"minimum":0,"description":"in'
      + 'put signals with smaller pulse durations are ignored [0.1 '
      + 'msec]","type":"integer"},"input_usage":{"minimum":0,"description":"0 '
      + '.. deactivated, 1 .. just detecting and timestamping","type":"integer"'
      + '},"out_polarity":{"minimum":0,"description":"0 .. positive edge, 1 .. '
      + 'negative '
      + 'edge","type":"integer"}},"description":"Trigger-Timestamping-Unit/IP '
      + 'configuration","title":"TTIP Configuration","required":["ttip_version"'
      + ',"num_channel","ext_channel","ext_signal","ext_delay","ext_subdivider"'
      + ',"ext_bitmask","dmi_incr","dmi_min_time","dmi_max_time","dmi_dist_per_'
      + 'tick","channel","output_descr","input_descr","output_usage","input_usa'
      + 'ge","out_polarity","out_duration","out_interval","out_delay","out_num_'
      + 'pulses","in_polarity","in_min_duration","in_max_duration","in_max_dela'
      + 'y"],"type":"object"}'
    );

    Example : (''
      + '{"out_num_pulses":1,"ext_signal":0,"dmi_max_time":0,"out_duration":300'
      + ',"in_max_duration":10000,"num_channel":9,"dmi_min_time":0,"out_interva'
      + 'l":10000,"in_polarity":0,"ext_delay":0,"channel":0,"in_max_delay":9990'
      + ',"output_usage":1,"ext_subdivider":1,"ttip_version":1,"out_delay":0,"i'
      + 'nput_descr":"Port 1 - '
      + 'Exposure","ext_channel":32,"ext_bitmask":0,"output_descr":"Port 1 - Tr'
      + 'igger","dmi_dist_per_tick":0.0,"dmi_incr":0,"in_min_duration":0,"input'
      + '_usage":1,"out_polarity":0}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ve'
      + 'rtex_file":{"properties":{"file_uuid":{"description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Vertex file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"description":"Details about vertex '
      + 'file","type":"object","title":"Vertex Information"}'
    );

    Example : (''
      + '{"vertex_file":{"file_uuid":"51534d95-d71f-4f36-ae1a-3e63a21fd1c7","fi'
      + 'le_extension":"vtx"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","oneOf":[{"proper'
      + 'ties":{"voxel_type":{"$ref":"#/definitions/voxel_type"},"shape_thresho'
      + 'lds":{"$ref":"#/definitions/shape_thresholds"},"voxel_origin":{"$ref":'
      + '"#/definitions/voxel_origin_enum"},"size":{"oneOf":[{"$ref":"#/definit'
      + 'ions/voxel_size"},{"$ref":"#/definitions/voxel_size_cubic"}],"descript'
      + 'ion":"Size of voxels in file coordinate system."}},"additionalProperti'
      + 'es":false,"required":["size","voxel_origin","voxel_type"]},{"propertie'
      + 's":{"shape_thresholds":{"$ref":"#/definitions/shape_thresholds"},"size'
      + '":{"$ref":"#/definitions/voxel_size","description":"Size of voxels in '
      + 'file coordinate system."},"voxel_type":{"$ref":"#/definitions/voxel_ty'
      + 'pe"},"reference_point":{"description":"Point in WGS84 geodetic decimal'
      + ' degree (EPSG:4326) that was used to compute the projection distortion'
      + ' parameters. The coefficient order is latitude, longitude. Only voxels'
      + ' with corresponding geo_tag, voxel_size and reference_point can be '
      + 'reliably processed together. This entry is available for voxel files '
      + 'in projected CRS only.","minItems":2,"maxItems":2,"items":{"minimum":-'
      + '180,"maximum":180,"type":"number"},"type":"array"},"voxel_origin":{"on'
      + 'eOf":[{"$ref":"#/definitions/voxel_origin_enum"},{"$ref":"#/definition'
      + 's/voxel_origin_point","description":"The base point of the voxel grid.'
      + ' Used together with <tt>voxel_size</tt> and <tt>voxel_index</tt> to '
      + 'compute actual point coordinates."}]},"size_llcs":{"$ref":"#/definitio'
      + 'ns/voxel_size","description":"Size of voxels in a locally levelled '
      + 'cartesian coordinate system (xyz). This is only used for voxels based '
      + 'on a map projection."}},"additionalProperties":false,"required":["refe'
      + 'rence_point","size_llcs","size","voxel_origin","voxel_type"]}],"descri'
      + 'ption":"Details about the voxels contained in the file","definitions":'
      + '{"voxel_size_cubic":{"$ref":"#/definitions/edge_length","type":"number'
      + '"},"shape_thresholds":{"properties":{"line":{"minimum":1,"description"'
      + ':"If the biggest eigenvalue is bigger than the median eigenvalue * '
      + 'line_threshold, the voxel is considered a line.","type":"number","excl'
      + 'usiveMinimum":true},"plane":{"minimum":0,"description":"If the '
      + 'smallest eigenvalue is smaller than the median eigenvalue * '
      + 'plane_threshold, the voxel is considered a plane.","exclusiveMaximum":'
      + 'true,"exclusiveMinimum":true,"maximum":1,"type":"number"}},"descriptio'
      + 'n":"Thresholds used to compute the voxel''s shape_id value.","required"'
      + ':["plane","line"],"type":"object"},"voxel_size":{"description":"Size '
      + 'of voxels.","minItems":3,"maxItems":3,"items":{"$ref":"#/definitions/e'
      + 'dge_length"},"type":"array"},"voxel_type":{"enum":["center","centroid"'
      + ',"index"],"description":"Whether a point in a voxel represents its '
      + 'center or its centroid. If type is <tt>index</tt> there is no point '
      + 'but only an integer voxel index.","default":"centroid"},"voxel_origin_'
      + 'enum":{"enum":["center","corner"],"description":"Defines whether the '
      + 'voxel''s center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.",'
      + '"default":"corner"},"voxel_origin_point":{"description":"Origin point '
      + 'for all voxel indices in voxel CRS.","minItems":3,"maxItems":3,"items"'
      + ':{"type":"number"},"type":"array"},"edge_length":{"minimum":0,"descrip'
      + 'tion":"Length of voxel edge '
      + '[m].","type":"number","exclusiveMinimum":true}},"title":"Voxel '
      + 'Information","type":"object"}'
    );

    Example : (''
      + '{"shape_thresholds":{"line":6,"plane":0.16},"size":[0.5971642834779395'
      + ',0.5971642834779395,0.5143705304787237],"voxel_type":"centroid","size_'
      + 'llcs":[0.5156575252891171,0.5130835356683303,0.5143705304787237],"voxe'
      + 'l_origin":"corner","reference_point":[48,16]}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"nu'
      + 'm_shots":{"minimum":1,"description":"Number of consecutive shots to be'
      + ' used for averaging.","type":"integer"},"mta_zone":{"minimum":1,"descr'
      + 'iption":"Fixed MTA zone for averaging.","type":"integer"},"trim":{"min'
      + 'imum":0,"description":"Percentage for robust averaging.","default":0,"'
      + 'maximum":0.5,"type":"number"}},"description":"Settings for waveform '
      + 'averaging","title":"Waveform Averaging '
      + 'Settings","required":["num_shots","mta_zone"],"type":"object"}'
    );

    Example : (''
      + '{"num_shots":7,"mta_zone":1,"trim":0.05}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"sa'
      + 'mple_data_files":{"items":{"properties":{"file_uuid":{"description":"F'
      + 'ile''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"channel_name":{"description":"Sample block '
      + 'channel name","type":"string"},"sample_bits":{"minimum":0,"description'
      + '":"Bitwidth of samples (e.g. 10 bit, 12 bit)","exclusiveMaximum":false'
      + ',"maximum":32,"exclusiveMinimum":false,"type":"integer"},"channel":{"m'
      + 'inimum":0,"description":"Sample block channel number (255 = invalid)",'
      + '"exclusiveMaximum":false,"maximum":255,"exclusiveMinimum":false,"type"'
      + ':"integer"},"laser_wavelength":{"minimum":0,"description":"Laser '
      + 'wavelength in meters (0 = unknown)","exclusiveMinimum":false,"type":"n'
      + 'umber"},"delta_st":{"description":"reserved","type":"number"},"file_ex'
      + 'tension":{"description":"Sample data file extension, without the '
      + 'leading dot","type":"string"},"sample_interval":{"minimum":0,"descript'
      + 'ion":"Sampling interval in seconds","exclusiveMinimum":false,"type":"n'
      + 'umber"}},"required":["channel","channel_name","sample_interval","sampl'
      + 'e_bits","laser_wavelength","delta_st","file_extension"],"type":"object'
      + '"},"type":"array"},"sample_block_file":{"properties":{"file_uuid":{"de'
      + 'scription":"File''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Sample block '
      + 'file extension, without the leading dot","type":"string"}},"required":'
      + '["file_extension"],"type":"object"},"range_offset_waveform_samples_m":'
      + '{"description":"Calibrated device specific range offset for waveform '
      + 'samples in '
      + 'meters.","type":"number"},"range_offset_m":{"description":"Calibrated '
      + 'device specific range offset for waveform analysis by system response '
      + 'fitting in meters.","type":"number"}},"description":"Details about '
      + 'waveform files","type":"object","required":["sample_block_file","sampl'
      + 'e_data_files"],"title":"Waveform Information"}'
    );

    Example : (''
      + '{"sample_block_file":{"file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe66'
      + '0","file_extension":"sbx"},"sample_data_files":[{"file_extension":"sp0'
      + '","file_uuid":"da084413-e3e8-4655-a122-071de8490d8e","channel_name":"h'
      + 'igh_power","sample_bits":12,"channel":0,"laser_wavelength":0,"delta_st'
      + '":0,"sample_interval":1.00503e-09},{"file_extension":"sp1","file_uuid"'
      + ':"93585b5e-5ea9-43a1-947b-e7ba3be642d2","channel_name":"low_power","sa'
      + 'mple_bits":12,"channel":1,"laser_wavelength":0,"delta_st":0,"sample_in'
      + 'terval":1.00503e-09},{"file_extension":"sp5","file_uuid":"9d2298c4-103'
      + '6-464f-b5cb-1cf8e517f3a0","channel_name":"wwf","sample_bits":12,"chann'
      + 'el":5,"laser_wavelength":0,"delta_st":0,"sample_interval":1.00503e-09}'
      + '],"range_offset_waveform_samples_m ":7.283,"range_offset_m":3.1415}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"Sc'
      + 'anner settings for waveform output","type":"array","items":{"propertie'
      + 's":{"smart_enabled":{"description":"Smart waveform output '
      + 'enabled","type":"boolean"},"sbl_name":{"description":"Name of sample '
      + 'block, e.g.: wfm, '
      + 'wwf","type":"string"},"pass_rng_greater":{"description":"Threshold for'
      + ' range greater than '
      + '[m]","type":"number"},"pass_ampl_less":{"description":"Threshold for '
      + 'amplitude less than '
      + '[dB]","type":"number"},"pass_dev_greater":{"description":"Threshold '
      + 'for deviation greater than '
      + '[1]","type":"integer"},"pass_rng_less":{"description":"Threshold for '
      + 'range less than '
      + '[m]","type":"number"},"enabled":{"description":"Waveform output '
      + 'enabled","type":"boolean"},"channel_idx_mask":{"description":"Bit mask'
      + ' for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, ...","type":"integer"},"logic_expression":{"description":"Logic '
      + 'expression of smart waveforms '
      + 'filter","type":"string"},"pass_dev_less":{"description":"Threshold for'
      + ' deviation less than '
      + '[1]","type":"integer"},"pass_ampl_greater":{"description":"Threshold '
      + 'for amplitude greater than [dB]","type":"number"}},"required":["sbl_na'
      + 'me","enabled","channel_idx_mask"],"type":"object"},"title":"Waveform '
      + 'Settings"}'
    );

    Example : (''
      + '[{"smart_enabled":true,"sbl_name":"wfm","pass_rng_greater":9.27,"pass_'
      + 'ampl_less":5.0,"pass_rng_less":13.11,"enabled":true,"channel_idx_mask"'
      + ':11,"pass_ampl_greater":1.0},{"enabled":false,"channel_idx_mask":32,"s'
      + 'bl_name":"wwf"}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"re'
      + 'sult":{"properties":{"range_sigma":{"description":"[m]","items":{"type'
      + '":"number"},"type":"array"},"angle":{"description":"[deg]","items":{"t'
      + 'ype":"number"},"type":"array"},"timestamp":{"description":"[s]","items'
      + '":{"type":"number"},"type":"array"},"amplitude_offset":{"description":'
      + '"[dB]","items":{"type":"number"},"type":"array"},"amplitude_sigma":{"d'
      + 'escription":"[dB]","items":{"type":"number"},"type":"array"},"amplitud'
      + 'e_mean":{"description":"[dB]","items":{"type":"number"},"type":"array"'
      + '},"range_mean":{"description":"[m]","items":{"type":"number"},"type":"'
      + 'array"}},"required":["angle","range_mean","range_sigma","amplitude_mea'
      + 'n","amplitude_sigma","amplitude_offset"],"type":"object"},"filter":{"p'
      + 'roperties":{"range_min":{"description":"[m]","items":{"type":"number"}'
      + ',"type":"array"},"angle":{"description":"[deg]","items":{"type":"numbe'
      + 'r"},"type":"array"},"range_max":{"description":"[m]","items":{"type":"'
      + 'number"},"type":"array"},"amplitude_max":{"description":"[dB]","items"'
      + ':{"type":"number"},"type":"array"}},"required":["angle","range_min","r'
      + 'ange_max","amplitude_max"],"type":"object"},"settings":{"properties":{'
      + '"amplitude":{"properties":{"sigma_factor":{"type":"number"},"additive_'
      + 'value":{"type":"number"}},"required":["sigma_factor","additive_value"]'
      + ',"type":"object"},"range":{"properties":{"sigma_factor":{"type":"numbe'
      + 'r"},"additive_value":{"type":"number"}},"required":["sigma_factor","ad'
      + 'ditive_value"],"type":"object"}},"required":["range","amplitude"],"typ'
      + 'e":"object"}},"description":"Window analysis data estimated from '
      + 'scandata and resulting filter parameters","title":"Window '
      + 'Analysis","required":["result","filter","settings"],"type":"object"}'
    );

    Example : (''
      + '{"result":{"range_sigma":[0.01869652,0.02151435,0.01747969,0.01918765,'
      + '0.01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.02'
      + '009433],"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.'
      + '9],"timestamp":[408.4441,411.4443],"amplitude_offset":[1.9,1.9],"ampli'
      + 'tude_sigma":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.43151'
      + '41,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],"amplitude_mean"'
      + ':[5.347396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983'
      + '473,5.007885,5.002441,4.982],"range_mean":[0.1105621,0.1079564,0.10870'
      + '88,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.105844'
      + '5,0.1031261]},"filter":{"range_min":[-0.208,-0.21,-0.212,-0.214,-0.216'
      + ',-0.218,-0.219,-0.221,-0.223,-0.225,-0.227],"angle":[14.9,15.0,15.1,15'
      + '.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"range_max":[0.424,0.425,0.426,'
      + '0.427,0.428,0.428,0.429,0.43,0.431,0.431,0.432],"amplitude_max":[8.04,'
      + '8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78]},"settings":{"amplitu'
      + 'de":{"sigma_factor":4,"additive_value":1.0},"range":{"sigma_factor":8,'
      + '"additive_value":0.1}}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"sl'
      + 'ices":{"items":{"properties":{"table":{"description":"Correction table'
      + ' (dimension defined by the ''amplitude'' and ''range'' '
      + 'objects)","minItems":1,"items":{"description":"Table row (= amplitude '
      + 'axis)","minItems":1,"items":{"description":"Table column (= range '
      + 'axis)","minItems":3,"maxItems":3,"items":{"description":"Table cell '
      + '(item 0: amplitude in dB, 1: range in m, 2: flags)","type":"number"},"'
      + 'type":"array"},"type":"array"},"type":"array"},"amplitude":{"descripti'
      + 'on":"Window echo amplitude of slice in '
      + 'dB","type":"number"}},"description":"Window echo correction parameter '
      + 'slice","required":["amplitude","table"],"type":"object"},"type":"array'
      + '"},"amplitude":{"properties":{"minimum":{"minimum":0.0,"description":"'
      + 'Minimum amplitude in '
      + 'dB","type":"number"},"entries":{"minimum":1,"description":"Number of '
      + 'amplitude entries","type":"integer"},"maximum":{"minimum":0.0,"descrip'
      + 'tion":"Maximum amplitude in '
      + 'dB","type":"number"}},"description":"Amplitude axis of correction tabl'
      + 'e","required":["minimum","maximum","entries"],"type":"object"},"range"'
      + ':{"properties":{"minimum":{"minimum":-2.0,"description":"Minimum range'
      + ' in m","maximum":2.0,"type":"number"},"entries":{"minimum":1,"descript'
      + 'ion":"Number of range entries","type":"integer"},"maximum":{"minimum":'
      + '-2.0,"description":"Maximum range in '
      + 'm","maximum":2.0,"type":"number"}},"description":"Range axis of '
      + 'correction table","required":["minimum","maximum","entries"],"type":"o'
      + 'bject"}},"description":"Correction parameters for window glass '
      + 'echoes","title":"Window Echo '
      + 'Correction","required":["amplitude","range","slices"],"type":"object"}'
    );

    Example : (''
      + '{"slices":[{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude"'
      + ':1.5},{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude":2.0}'
      + '],"amplitude":{"minimum":2,"entries":128,"maximum":20},"range":{"minim'
      + 'um":-1.5060822940732335,"entries":128,"maximum":1.5060822940732335}}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_DEVICES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Name)));
  RDB_RIEGL_DEVICES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Title)));
  RDB_RIEGL_DEVICES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Description)));
  RDB_RIEGL_DEVICES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Schema)));
  RDB_RIEGL_DEVICES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Example)));

  RDB_RIEGL_DYNTRIG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Name)));
  RDB_RIEGL_DYNTRIG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Title)));
  RDB_RIEGL_DYNTRIG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Description)));
  RDB_RIEGL_DYNTRIG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Schema)));
  RDB_RIEGL_DYNTRIG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_ITEM_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Name)));
  RDB_RIEGL_ITEM_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Title)));
  RDB_RIEGL_ITEM_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Description)));
  RDB_RIEGL_ITEM_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Schema)));
  RDB_RIEGL_ITEM_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_STORED_FILTERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Name)));
  RDB_RIEGL_STORED_FILTERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Title)));
  RDB_RIEGL_STORED_FILTERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Description)));
  RDB_RIEGL_STORED_FILTERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Schema)));
  RDB_RIEGL_STORED_FILTERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Example)));

  RDB_RIEGL_SYSTEM_DESCRIPTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Name)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Title)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Description)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Schema)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_TTIP_CONFIGURATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Name)));
  RDB_RIEGL_TTIP_CONFIGURATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Title)));
  RDB_RIEGL_TTIP_CONFIGURATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Description)));
  RDB_RIEGL_TTIP_CONFIGURATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Schema)));
  RDB_RIEGL_TTIP_CONFIGURATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 52); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DYNTRIG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ITEM_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_STORED_FILTERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SYSTEM_DESCRIPTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TTIP_CONFIGURATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
